@@ -9,9 +9,9 @@
 #' @param alpha The alpha of the fill. Defaults to 1. 
 #' @param size_line The size of the outlines of bars.
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -61,9 +61,9 @@ gg_bar <- function(data,
                     alpha = 1,
                     size_line = 0.5,
                     title = NULL,
-                    title_wrap = 70,
+                    title_wrap = 100,
                     subtitle = NULL,
-                    subtitle_wrap = 80,
+                    subtitle_wrap = 100,
                     x_balance = FALSE,
                     x_expand = NULL,
                     x_labels = NULL,
@@ -145,7 +145,7 @@ gg_bar <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = mobile)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
-  if (is.null(pal)) pal <- sv_pal(1)
+  if (is.null(pal)) pal <- pal_viridis_reorder(1)
   else pal <- pal[1]
   
   if (lubridate::is.Date(x_var_vctr)) bar_unit <- 365
@@ -284,9 +284,9 @@ gg_bar <- function(data,
 #' @param alpha The alpha of the fill. Defaults to 1. 
 #' @param size_line The size of the outlines of bars.
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -347,9 +347,9 @@ gg_bar_col <- function(data,
                         alpha = 1,
                         size_line = 0.5,
                         title = NULL,
-                        title_wrap = 70,
+                        title_wrap = 100,
                         subtitle = NULL,
-                        subtitle_wrap = 80,
+                        subtitle_wrap = 100,
                         x_balance = FALSE,
                         x_expand = NULL,
                         x_labels = NULL,
@@ -468,12 +468,12 @@ gg_bar_col <- function(data,
   bar_width <- bar_unit * width
   
   if (is.factor(col_var_vctr) & !is.null(levels(col_var_vctr))) {
-    n_col <- length(levels(col_var_vctr))
+    col_n <- length(levels(col_var_vctr))
   }
-  else n_col <- length(unique(col_var_vctr))
+  else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- sv_pal(n_col)
-  else pal <- pal[1:n_col]
+  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
   
@@ -584,13 +584,13 @@ gg_bar_col <- function(data,
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     ) +
     scale_colour_manual(
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     ) 
   
   if (mobile == FALSE) {
@@ -644,9 +644,9 @@ gg_bar_col <- function(data,
 #' @param alpha The alpha of the fill. Defaults to 1.
 #' @param size_line The size of the outlines of bars. 
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -700,9 +700,9 @@ gg_bar_facet <- function(data,
                           alpha = 1,
                           size_line = 0.5,
                           title = NULL,
-                          title_wrap = 70,
+                          title_wrap = 100,
                           subtitle = NULL,
-                          subtitle_wrap = 80,
+                          subtitle_wrap = 100,
                           x_balance = FALSE,
                           x_expand = NULL,
                           x_labels = NULL,
@@ -789,7 +789,7 @@ gg_bar_facet <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = FALSE)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
-  if (is.null(pal)) pal <- sv_pal(1)
+  if (is.null(pal)) pal <- pal_viridis_reorder(1)
   else pal <- pal[1]
   
   if (lubridate::is.Date(x_var_vctr)) bar_unit <- 365
@@ -924,9 +924,9 @@ gg_bar_facet <- function(data,
 #' @param alpha The alpha of the fill. Defaults to 1. 
 #' @param size_line The size of the outlines of bars.
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -990,9 +990,9 @@ gg_bar_col_facet <- function(data,
                               alpha = 1,
                               size_line = 0.5,
                               title = NULL,
-                              title_wrap = 70,
+                              title_wrap = 100,
                               subtitle = NULL,
-                              subtitle_wrap = 80,
+                              subtitle_wrap = 100,
                               x_balance = FALSE,
                               x_expand = NULL,
                               x_labels = NULL,
@@ -1128,12 +1128,12 @@ gg_bar_col_facet <- function(data,
   bar_width <- bar_unit * width
   
   if (is.factor(col_var_vctr) & !is.null(levels(col_var_vctr))) {
-    n_col <- length(levels(col_var_vctr))
+    col_n <- length(levels(col_var_vctr))
   }
-  else n_col <- length(unique(col_var_vctr))
+  else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- sv_pal(n_col)
-  else pal <- pal[1:n_col]
+  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
   
@@ -1252,13 +1252,13 @@ gg_bar_col_facet <- function(data,
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     ) +
     scale_colour_manual(
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     ) +
     labs(
       title = stringr::str_wrap(title, title_wrap),
