@@ -9,9 +9,9 @@
 #' @param alpha The alpha of the fill. Defaults to 1. 
 #' @param size_line The size of the outlines of bars.
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 65. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 80. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -61,9 +61,9 @@ gg_hbar <- function(data,
                     alpha = 1,
                     size_line = 0.5,
                     title = NULL,
-                    title_wrap = 65,
+                    title_wrap = 80,
                     subtitle = NULL,
-                    subtitle_wrap = 75,
+                    subtitle_wrap = 80,
                     x_balance = FALSE,
                     x_expand = NULL,
                     x_labels = waiver(),
@@ -145,7 +145,7 @@ gg_hbar <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = mobile)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
-  if (is.null(pal)) pal <- sv_pal(1)
+  if (is.null(pal)) pal <- pal_viridis_reorder(1)
   else pal <- pal[1]
   
   if (lubridate::is.Date(y_var_vctr)) bar_unit <- 365
@@ -288,9 +288,9 @@ gg_hbar <- function(data,
 #' @param alpha The alpha of the fill. Defaults to 1. 
 #' @param size_line The size of the outlines of bars.
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 65. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 80. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -352,9 +352,9 @@ gg_hbar_col <- function(data,
                         alpha = 1,
                         size_line = 0.5,
                         title = NULL,
-                        title_wrap = 65,
+                        title_wrap = 80,
                         subtitle = NULL,
-                        subtitle_wrap = 75,
+                        subtitle_wrap = 80,
                         x_balance = FALSE,
                         x_expand = NULL,
                         x_labels = waiver(),
@@ -450,7 +450,7 @@ gg_hbar_col <- function(data,
     }
   }
   
-  if (col_rev == TRUE){
+  if (col_rev == FALSE){
     if (is.factor(col_var_vctr)){
       data <- data %>%
         dplyr::mutate(dplyr::across(!!col_var, ~forcats::fct_rev(.x)))
@@ -474,14 +474,14 @@ gg_hbar_col <- function(data,
   bar_width <- bar_unit * width
   
   if (is.factor(col_var_vctr) & !is.null(levels(col_var_vctr))) {
-    n_col <- length(levels(col_var_vctr))
+    col_n <- length(levels(col_var_vctr))
   }
-  else n_col <- length(unique(col_var_vctr))
+  else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- sv_pal(n_col)
-  else pal <- pal[1:n_col]
+  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  else pal <- pal[1:col_n]
   
-  if (pal_rev == TRUE) pal <- rev(pal)
+  if (pal_rev == FALSE) pal <- rev(pal)
   
   plot <- ggplot(data) +
     theme_hbar(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
@@ -594,13 +594,13 @@ gg_hbar_col <- function(data,
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     ) +
     scale_colour_manual(
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     ) 
   
   if (mobile == FALSE) {
@@ -615,11 +615,13 @@ gg_hbar_col <- function(data,
       guides(fill = guide_legend(
         ncol = col_legend_ncol,
         byrow = TRUE,
+        reverse = TRUE, 
         title = stringr::str_wrap(col_title, col_title_wrap)
       ), 
       col = guide_legend(
         ncol = col_legend_ncol, nrow = col_legend_nrow, 
         byrow = TRUE,
+        reverse = TRUE, 
         title = stringr::str_wrap(col_title, col_title_wrap)
       ))
   }
@@ -654,9 +656,9 @@ gg_hbar_col <- function(data,
 #' @param alpha The alpha of the fill. Defaults to 1.
 #' @param size_line The size of the outlines of bars. 
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 65. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 80. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -710,9 +712,9 @@ gg_hbar_facet <- function(data,
                           alpha = 1,
                           size_line = 0.5,
                           title = NULL,
-                          title_wrap = 65,
+                          title_wrap = 80,
                           subtitle = NULL,
-                          subtitle_wrap = 75,
+                          subtitle_wrap = 80,
                           x_balance = FALSE,
                           x_expand = NULL,
                           x_labels = waiver(),
@@ -799,7 +801,7 @@ gg_hbar_facet <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = FALSE)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
-  if (is.null(pal)) pal <- sv_pal(1)
+  if (is.null(pal)) pal <- pal_viridis_reorder(1)
   else pal <- pal[1]
   
   if (lubridate::is.Date(y_var_vctr)) bar_unit <- 365
@@ -943,9 +945,9 @@ gg_hbar_facet <- function(data,
 #' @param alpha The alpha of the fill. Defaults to 1.
 #' @param size_line The size of the outlines of bars. 
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 65. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 80. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -1009,9 +1011,9 @@ gg_hbar_col_facet <- function(data,
                               alpha = 1,
                               size_line = 0.5,
                               title = NULL,
-                              title_wrap = 65,
+                              title_wrap = 80,
                               subtitle = NULL,
-                              subtitle_wrap = 75,
+                              subtitle_wrap = 80,
                               x_balance = FALSE,
                               x_expand = NULL,
                               x_labels = waiver(),
@@ -1147,14 +1149,14 @@ gg_hbar_col_facet <- function(data,
   bar_width <- bar_unit * width
   
   if (is.factor(col_var_vctr) & !is.null(levels(col_var_vctr))) {
-    n_col <- length(levels(col_var_vctr))
+    col_n <- length(levels(col_var_vctr))
   }
-  else n_col <- length(unique(col_var_vctr))
+  else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- sv_pal(n_col)
-  else pal <- pal[1:n_col]
+  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  else pal <- pal[1:col_n]
   
-  if (pal_rev == TRUE) pal <- rev(pal)
+  if (pal_rev == FALSE) pal <- rev(pal)
   
   plot <- ggplot(data) +
     theme_hbar(
@@ -1283,22 +1285,24 @@ gg_hbar_col_facet <- function(data,
         values = pal,
         drop = FALSE,
         labels = col_labels,
-        na.value = "#A8A8A8"
+        na.value = "#7F7F7FFF"
       ) +
       scale_colour_manual(
         values = pal,
         drop = FALSE,
         labels = col_labels,
-        na.value = "#A8A8A8"
+        na.value = "#7F7F7FFF"
       ) +
       guides(fill = guide_legend(
         ncol = col_legend_ncol,
         byrow = TRUE,
+        reverse = TRUE, 
         title = stringr::str_wrap(col_title, col_title_wrap)
       ), 
       col = guide_legend(
         ncol = col_legend_ncol, nrow = col_legend_nrow, 
         byrow = TRUE,
+        reverse = TRUE, 
         title = stringr::str_wrap(col_title, col_title_wrap)
       )) +
       labs(
