@@ -8,9 +8,9 @@
 #' @param size_point Size of points. Defaults to 1. 
 #' @param size_line Size of lines. Defaults to 0.5. 
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. Not applicable where mobile equals TRUE.
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. Not applicable where mobile equals TRUE.
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. Not applicable where mobile equals TRUE.
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. Not applicable where mobile equals TRUE.
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -59,9 +59,9 @@ gg_line <- function(data,
                     size_point = 1,
                     size_line = 0.5,
                     title = NULL,
-                    title_wrap = 70,
+                    title_wrap = 100,
                     subtitle = NULL,
-                    subtitle_wrap = 80,
+                    subtitle_wrap = 100,
                     x_balance = FALSE,
                     x_expand = NULL,
                     x_labels = NULL,
@@ -134,7 +134,7 @@ gg_line <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = mobile)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
-  if (is.null(pal)) pal <- sv_pal(1)
+  if (is.null(pal)) pal <- pal_viridis_reorder(1)
   else pal <- pal[1]
   
   plot <- ggplot(data) +
@@ -273,9 +273,9 @@ gg_line <- function(data,
 #' @param size_point Size of points. Defaults to 1. 
 #' @param size_line Size of lines. Defaults to 0.5. 
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. Not applicable where mobile equals TRUE.
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. Not applicable where mobile equals TRUE.
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. Not applicable where mobile equals TRUE.
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. Not applicable where mobile equals TRUE.
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -332,9 +332,9 @@ gg_line_col <- function(data,
                         size_point = 1,
                         size_line = 0.5,
                         title = NULL,
-                        title_wrap = 70,
+                        title_wrap = 100,
                         subtitle = NULL,
-                        subtitle_wrap = 80,
+                        subtitle_wrap = 100,
                         x_balance = FALSE,
                         x_expand = NULL,
                         x_labels = NULL,
@@ -430,12 +430,12 @@ gg_line_col <- function(data,
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
   if (is.factor(col_var_vctr) & !is.null(levels(col_var_vctr))) {
-    n_col <- length(levels(col_var_vctr))
+    col_n <- length(levels(col_var_vctr))
   }
-  else n_col <- length(unique(col_var_vctr))
+  else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- sv_pal(n_col)
-  else pal <- pal[1:n_col]
+  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
   
@@ -545,7 +545,7 @@ gg_line_col <- function(data,
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     )
   
   if (mobile == FALSE) {
@@ -586,9 +586,9 @@ gg_line_col <- function(data,
 #' @param size_point Size of points. Defaults to 1. 
 #' @param size_line Size of lines. Defaults to 0.5. 
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -642,9 +642,9 @@ gg_line_facet <- function(data,
                           size_point = 1,
                           size_line = 0.5,
                           title = NULL,
-                          title_wrap = 70,
+                          title_wrap = 100,
                           subtitle = NULL,
-                          subtitle_wrap = 80,
+                          subtitle_wrap = 100,
                           x_balance = FALSE,
                           x_expand = NULL,
                           x_labels = NULL,
@@ -734,7 +734,7 @@ gg_line_facet <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = FALSE)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
-  if (is.null(pal)) pal <- sv_pal(1)
+  if (is.null(pal)) pal <- pal_viridis_reorder(1)
   else pal <- pal[1]
   
   plot <- ggplot(data) +
@@ -869,9 +869,9 @@ gg_line_facet <- function(data,
 #' @param size_point Size of points. Defaults to 1. 
 #' @param size_line Size of lines. Defaults to 0.5. 
 #' @param title Title string. Defaults to NULL.
-#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. 
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
-#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -933,9 +933,9 @@ gg_line_col_facet <- function(data,
                               size_point = 1,
                               size_line = 0.5,
                               title = NULL,
-                              title_wrap = 70,
+                              title_wrap = 100,
                               subtitle = NULL,
-                              subtitle_wrap = 80,
+                              subtitle_wrap = 100,
                               x_balance = FALSE,
                               x_expand = NULL,
                               x_labels = NULL,
@@ -1049,12 +1049,12 @@ gg_line_col_facet <- function(data,
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
   if (is.factor(col_var_vctr) & !is.null(levels(col_var_vctr))) {
-    n_col <- length(levels(col_var_vctr))
+    col_n <- length(levels(col_var_vctr))
   }
-  else n_col <- length(unique(col_var_vctr))
+  else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- sv_pal(n_col)
-  else pal <- pal[1:n_col]
+  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
   
@@ -1171,7 +1171,7 @@ gg_line_col_facet <- function(data,
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = "#A8A8A8"
+      na.value = "#7F7F7FFF"
     ) +
     labs(
       title = stringr::str_wrap(title, title_wrap),
